# Estimator Overview

The table below gives an overview of all estimators in aeon.

<p>
<label for="myInput"></label><input type="text" id="myInput" placeholder="Search the table ..." />
<br>
</p>

```{include} estimator_overview_table.md
```
